==> kadaster-gds2-1.2-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstopvragenresultaat/afgifte/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.afgifte.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.afgifte.v20130701 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BestandenLijst_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701", "BestandenLijst");
    private final static QName _AfgifteBestand_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701", "AfgifteBestand");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.afgifte.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteBestandType }
     * 
     */
    public AfgifteBestandType createAfgifteBestandType() {
        return new AfgifteBestandType();
    }

    /**
     * Create an instance of {@link BestandenLijstType }
     * 
     */
    public BestandenLijstType createBestandenLijstType() {
        return new BestandenLijstType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandenLijstType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701", name = "BestandenLijst")
    public JAXBElement<BestandenLijstType> createBestandenLijst(BestandenLijstType value) {
        return new JAXBElement<BestandenLijstType>(_BestandenLijst_QNAME, BestandenLijstType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteBestandType }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701", name = "AfgifteBestand")
    public JAXBElement<AfgifteBestandType> createAfgifteBestand(AfgifteBestandType value) {
        return new JAXBElement<AfgifteBestandType>(_AfgifteBestand_QNAME, AfgifteBestandType.class, null, value);
    }

}

==> kadaster-gds2-2.3-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstopvragenresultaat/afgifte/v20130701/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.afgifte.v20130701;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.afgifte.v20130701 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _AfgifteBestand_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701", "AfgifteBestand");
    private final static QName _BestandenLijst_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701", "BestandenLijst");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.afgifte_bestandenlijstopvragenresultaat.afgifte.v20130701
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link AfgifteBestandType }
     * 
     */
    public AfgifteBestandType createAfgifteBestandType() {
        return new AfgifteBestandType();
    }

    /**
     * Create an instance of {@link BestandenLijstType }
     * 
     */
    public BestandenLijstType createBestandenLijstType() {
        return new BestandenLijstType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link AfgifteBestandType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link AfgifteBestandType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701", name = "AfgifteBestand")
    public JAXBElement<AfgifteBestandType> createAfgifteBestand(AfgifteBestandType value) {
        return new JAXBElement<AfgifteBestandType>(_AfgifteBestand_QNAME, AfgifteBestandType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BestandenLijstType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BestandenLijstType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstopvragenresultaat/afgifte/v20130701", name = "BestandenLijst")
    public JAXBElement<BestandenLijstType> createBestandenLijst(BestandenLijstType value) {
        return new JAXBElement<BestandenLijstType>(_BestandenLijst_QNAME, BestandenLijstType.class, null, value);
    }

}
